# Snyk.io

According to the website snyk.io: Find and automatically fix vulnerabilities in your code, open source dependencies, containers, and infrastructure as code — all powered by Snyk’s industry-leading security intelligence.

This boefje uses the vulnerability database to search for vulnerabilities, based on a Software version.

### Input OOIs

Snyk expects an Software as input.

### Output OOIs

Snyk currently outputs the following OOIs:

|OOI type|Description|
|---|---|
|KATFinding|Known vulnerabilty of software|
